#include <iostream>
#include <string>
#include <map>

using namespace std;

void addNewBook(map<string, string>& library) {
	string isbn;
	cout << "Enter the book ISBN: ";
	cin >> isbn;

	bool bookAlreadyExists = library.find(isbn) != library.end();
	if (bookAlreadyExists) {
		cout << "A book with the specified ISBN already exists!" << endl;
		return;
	}

	cin.ignore(); // Calling this to allow the book title to have spaces in them
	string title;
	cout << "Enter the book title: ";
	getline(cin, title);

	library[isbn] = title;
	cout << "Successfully added a new book!" << endl;
}

void printBookInfo(map<string, string>& library) {
	string isbn;
	cout << "Enter the ISBN of the book: ";
	cin >> isbn;

	bool bookExists = library.find(isbn) != library.end();

	if (bookExists) {
		cout << "Title: " << library[isbn] << ", ISBN: " << isbn << endl;
	}
	else {
		cout << "The book with the specified ISBN does not exist!" << endl;
	}
}

void removeBook(map<string, string>& library) {
	string isbn;
	cout << "Enter the ISBN of the book you would like to remove: ";
	cin >> isbn;

	bool bookExists = library.find(isbn) != library.end();

	if (bookExists) {
		string title = library[isbn];
		library.erase(isbn);
		cout << "Successfully removed the book \"" << title << "\"!" << endl;
	}
	else {
		cout << "The book with the specified ISBN does not exist." << endl;
	}
}

void printAllBooks(map<string, string>& library) {
	if (library.empty()) {
		cout << "The library is empty!" << endl;
		return;
	}

	for (auto& b : library) {
		cout << "Title: " << b.second << ", ISBN: " << b.first << endl;
	}
}

void checkUserInput(map<string, string>& library) {
	int userChoice;

	do {
		cout << "Please select one of the following options:" << endl;
		cout << "1. Add a new book" << endl;
		cout << "2. Print book info" << endl;
		cout << "3. Remove a book" << endl;
		cout << "4. Print all books" << endl;
		cout << "5. Exit" << endl;

		cout << "Your choice: ";
		cin >> userChoice;
		cout << endl;

		switch (userChoice) {
		case 1:
			addNewBook(library);
			break;
		case 2:
			printBookInfo(library);
			break;
		case 3:
			removeBook(library);
			break;
		case 4:
			printAllBooks(library);
			break;
		case 5:
			// We just exit the program
			break;
		default:
			cout << "Invalid input!" << endl;
				break;
		}
		
		cout << endl;
	} while (userChoice != 5);
}

int main() {
	map<string, string> library;

	checkUserInput(library);

	return 0;
}